@@ -15,7 +15,7 @@ Test::Count::Parser - A Parser for Test::Count.
 
 =cut
 
-our $VERSION = '0.0600';
+our $VERSION = '0.0700';
 
 sub _get_grammar
 {
@@ -231,7 +231,7 @@ sub get_count
 
 =head1 AUTHOR
 
-Shlomi Fish, C<< <shlomif at cpan.org> >>
+Shlomi Fish, L<http://www.shlomifish.org/> .
 
 =head1 BUGS
 
